==> kdeutils-4.1.1.tar.bz2: kdeutils-4.1.1/okteta/program/libkakao/controllers/io/setremote/setremotecontroller.h <==
/*
    This file is part of the Kakao Framework, part of the KDE project.

    Copyright 2007 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SETREMOTECONTROLLER_H
#define SETREMOTECONTROLLER_H


// lib
#include <kviewcontroller.h>

class KAction;
class KXmlGuiWindow;
class KAbstractDocument;
class KDocumentSyncManager;

class SetRemoteController : public KViewController
{
  Q_OBJECT

  public:
    SetRemoteController( KDocumentSyncManager *syncManager, KXmlGuiWindow *window );

  public: // KViewController API
    virtual void setView( KAbstractView *view );

  protected Q_SLOTS:
    void saveAs();

  protected:
    KXmlGuiWindow *mMainWindow;
    KAction *mSaveAsAction;

    KDocumentSyncManager *mSyncManager;
    KAbstractDocument *mDocument;
};

#endif

==> kdeutils-4.2.0.tar.bz2: kdeutils-4.2.0/okteta/program/libkakao/controllers/io/setremote/setremotecontroller.h <==
/*
    This file is part of the Kakao Framework, part of the KDE project.

    Copyright 2007-2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SETREMOTECONTROLLER_H
#define SETREMOTECONTROLLER_H


// lib
#include <abstractxmlguicontroller.h>

class KAction;
class KXMLGUIClient;
class KAbstractDocument;
class KDocumentSyncManager;

class SetRemoteController : public AbstractXmlGuiController
{
  Q_OBJECT

  public:
    SetRemoteController( KDocumentSyncManager* syncManager, KXMLGUIClient* guiClient );

  public: // AbstractXmlGuiController API
    virtual void setTargetModel( AbstractModel* model );

  protected Q_SLOTS:
    void saveAs();

  protected:
    KAction *mSaveAsAction;

    KDocumentSyncManager *mSyncManager;
    KAbstractDocument *mDocument;
};

#endif
